#!/bin/sh
echo 'name: network
version: 2.3.1.0
id: network-2.3.1.0-e56ec3d5abd17b7b386690bf49d424ab

license: BSD3
copyright:
maintainer: Johan Tibell <johan.tibell@gmail.com>
stability:
homepage: http://github.com/haskell/network
package-url:
synopsis: Low-level networking interface
description: Low-level networking interface
category: Network
author:
pkgpath: devel/hs-network
exposed: True
exposed-modules: Network Network.BSD Network.Socket
                 Network.Socket.ByteString Network.Socket.ByteString.Lazy
                 Network.Socket.Internal Network.URI
hidden-modules: Network.Socket.ByteString.IOVec
                Network.Socket.ByteString.MsgHdr Network.Socket.ByteString.Internal
trusted: False
import-dirs: /usr/local/lib/ghc/network-2.3.1.0
library-dirs: /usr/local/lib/ghc/network-2.3.1.0
hs-libraries: HSnetwork-2.3.1.0
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/lib/ghc/network-2.3.1.0/include
includes: HsNet.h
depends: base-4.5.1.0-5b1c9d3d412ed227632edae6d2aca151
         bytestring-0.9.2.1-3c5b69d9d36e3a0179d120b97025ab86
         parsec-3.1.3-fb970d7908f363dfef34b141200235e6
         unix-2.5.1.1-c23dadb7ccff9eeb5d1df0bd91909ca9
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-network-2.3.1.0/html/network.haddock
haddock-html: /usr/local/share/doc/hs-network-2.3.1.0/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
